package com.test.test.service.impl;

import java.util.List;

import com.test.common.utils.DateUtils;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import com.test.test.mapper.TestApiMapper;
import com.test.test.domain.TestApi;
import com.test.test.service.ITestApiService;

/**
 * 接口Service业务层处理
 *
 * @author xiaoe
 * @date 2025-02-08
 */
@Service
public class TestApiServiceImpl implements ITestApiService {
    @Resource
    private TestApiMapper testApiMapper;

    /**
     * 查询接口
     *
     * @param id 接口主键
     * @return 接口
     */
    @Override
    public TestApi selectTestApiById(Long id) {
        return testApiMapper.selectTestApiById(id);
    }

    /**
     * 查询接口列表
     *
     * @param testApi 接口
     * @return 接口
     */
    @Override
    public List<TestApi> selectTestApiList(TestApi testApi) {
        return testApiMapper.selectTestApiList(testApi);
    }

    /**
     * 新增接口
     *
     * @param testApi 接口
     * @return 结果
     */
    @Override
    public int insertTestApi(TestApi testApi) {
        testApi.setCreateTime(DateUtils.getNowDate());
        return testApiMapper.insertTestApi(testApi);
    }

    /**
     * 修改接口
     *
     * @param testApi 接口
     * @return 结果
     */
    @Override
    public int updateTestApi(TestApi testApi) {
        testApi.setUpdateTime(DateUtils.getNowDate());
        return testApiMapper.updateTestApi(testApi);
    }

    /**
     * 批量删除接口
     *
     * @param ids 需要删除的接口主键
     * @return 结果
     */
    @Override
    public int deleteTestApiByIds(Long[] ids) {
        return testApiMapper.deleteTestApiByIds(ids);
    }

    /**
     * 删除接口信息
     *
     * @param id 接口主键
     * @return 结果
     */
    @Override
    public int deleteTestApiById(Long id) {
        return testApiMapper.deleteTestApiById(id);
    }
}
